#---------------------------------------------------------------------
#    Name: odmfields.awk
#  Author: Robert A. (Bob) Gibson [rag]
# Purpose: Process records from an odmget, extracting specific fields
#          and displaying them in a particular order
#   Usage: awk -f odmfields.awk
# Example: 
#          ODMDIR=/usr/lib/objrepos odmget vendor | awk -f odmfields.awk
# History: 
#   date   ver who Description
# -------- --- --- -----------------------------------------------
# 04/07/16 1.0 rag New - based upon requirements provided by Joe M.
#---------------------------------------------------------------------
BEGIN {
  OFS = "|"
  NumFields = 0
  GUID      = ""
  DDIR      = ""
  INSTANCE  = ""
  LPPID     = ""
  TIME      = ""
}
NF == 0 {
  if ( NumFields > 0 ) {
    print DDIR, GUID, INSTANCE, LPPID, TIME
    NumFields = 0
    GUID      = ""
    DDIR      = ""
    INSTANCE  = ""
    LPPID     = ""
    TIME      = ""
  }
}
NF > 2 {
  if ( $1 == "GUID" ) {
    GUID = substr( $3, 2, length( $3 ) - 2 )
    NumFields++
  }
  if ( $1 == "ddir" ) {
    if ( NF > 3 ) {
      x = index( $0, "=" ) + 2
      DDIR = substr( $0, x )
      DDIR = substr( DDIR, 2, length( DDIR ) - 2 )
    } else { 
      DDIR = substr( $3, 2, length( $3 ) - 2 )
    }
    NumFields++
  }
  if ( $1 == "instance" ) {
    INSTANCE = $3
    NumFields++
  }
  if ( $1 == "lpp_id" ) {
    LPPID    = $3
    NumFields++
  }
  if ( $1 == "time" ) {
    TIME = $3
    NumFields++
  }
}
END {
  if ( NumFields > 0 ) {
    print DDIR, GUID, INSTANCE, LPPID, TIME
  }
}
